@@ -1,24 +1,23 @@
-## Copyright (C) 1995, 1996, 1997, 1998, 2000, 2002, 2005, 2007
-##               Friedrich Leisch
+## Copyright (C) 1995-2019 Friedrich Leisch
 ##
 ## This file is part of Octave.
 ##
-## Octave is free software; you can redistribute it and/or modify it
+## Octave is free software: you can redistribute it and/or modify it
 ## under the terms of the GNU General Public License as published by
-## the Free Software Foundation; either version 3 of the License, or (at
-## your option) any later version.
+## the Free Software Foundation, either version 3 of the License, or
+## (at your option) any later version.
 ##
 ## Octave is distributed in the hope that it will be useful, but
 ## WITHOUT ANY WARRANTY; without even the implied warranty of
-## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-## General Public License for more details.
+## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+## GNU General Public License for more details.
 ##
 ## You should have received a copy of the GNU General Public License
 ## along with Octave; see the file COPYING.  If not, see
-## <http://www.gnu.org/licenses/>.
+## <https://www.gnu.org/licenses/>.
 
 ## -*- texinfo -*-
-## @deftypefn {Function File} {} fractdiff (@var{x}, @var{d})
+## @deftypefn {} {} fractdiff (@var{x}, @var{d})
 ## Compute the fractional differences @math{(1-L)^d x} where @math{L}
 ## denotes the lag-operator and @math{d} is greater than -1.
 ## @end deftypefn
@@ -35,11 +34,11 @@ function retval = fractdiff (x, d)
   N = 100;
 
   if (! isvector (x))
-    error ("fractdiff: x must be a vector")
+    error ("fractdiff: X must be a vector");
   endif
 
   if (! isscalar (d))
-    error ("fractdiff: d must be a scalar")
+    error ("fractdiff: D must be a scalar");
   endif
 
 
@@ -63,7 +62,7 @@ function retval = fractdiff (x, d)
     endif
 
   else
-    error ("fractdiff: d must be > -1");
+    error ("fractdiff: D must be > -1");
 
   endif
 
